==> web-6.0.0.tgz: package/lib/combo/ParTreeItem.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
import { activeStatus, DropItem } from "./DropItem";
import { VelocityComponent } from "velocity-react";
import { CheckBox } from "../input/index";
class ParTreeItem extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.checkFn = (e) => {
            const dom = e.currentTarget;
            const value = dom.value;
            this.props.checkForPar(value);
        };
        this.toggleExpandFn = (e) => {
            const dom = e.currentTarget;
            const index = dom.dataset.index;
            this.props.toggleExpand(index);
        };
        this.textClickFn = (e) => {
            e.stopPropagation();
        };
    }
    getCheckbox(text, expand) {
        const { fieldObj, node, index } = this.props;
        const multiply = fieldObj.get("multiply");
        const active = node.get("active");
        const hasChecked = activeStatus.hasSelect === active;
        const checked = activeStatus.select === active;
        const icon = React.createElement(SvgIcon, { className: expand ? "folder-open" : "folder" });
        return multiply ? (React.createElement(CheckBox, { hasChecked: hasChecked, checked: checked, value: index, changeHandle: this.checkFn },
            icon,
            React.createElement("span", { className: "combo-text" }, text))) : (React.createElement(React.Fragment, null,
            icon,
            React.createElement("span", { className: "combo-text" }, text)));
    }
    getSubCom(child, lev, oindex) {
        const { fieldObj, clickFn, checkForPar, checkMethod, toggleExpand, formatterDropItem } = this.props;
        const idField = fieldObj.get("idField");
        const multiply = fieldObj.get("multiply");
        return child.map((val, index) => {
            const child = val.get(fieldObj.get("childField"));
            return !child.size ? (React.createElement(DropItem, { key: val.get(idField), node: val, fieldObj: fieldObj, index: `${oindex},${index}`, lev: lev + 1, clickFn: clickFn, formatterDropItem: formatterDropItem, checkMethod: checkMethod, CheckBox: multiply ? CheckBox : undefined })) : (React.createElement(ParTreeItem, { key: val.get(idField), node: val, fieldObj: fieldObj, clickFn: clickFn, index: `${oindex},${index}`, lev: lev + 1, checkForPar: checkForPar, formatterDropItem: formatterDropItem, checkMethod: checkMethod, toggleExpand: toggleExpand }));
        });
    }
    render() {
        const { lev, node, index, fieldObj, formatterDropItem } = this.props;
        const levSpaceStyle = { paddingLeft: `${lev}em`, };
        const text = formatterDropItem
            ? formatterDropItem(node)
            : node.get(fieldObj.get("textField"));
        const expand = node.get("expand");
        const child = node.get(fieldObj.get("childField"));
        const multiply = fieldObj.get("multiply");
        return (React.createElement("li", { className: "combo-par-item" },
            React.createElement("div", { className: `m-combo-item`, "data-index": index, onClick: this.toggleExpandFn },
                React.createElement("span", { className: "g-item-text", style: levSpaceStyle, onClick: multiply ? this.textClickFn : undefined }, this.getCheckbox(text, expand)),
                React.createElement(SvgIcon, { className: `arrow-${expand ? "up" : "down"}` })),
            React.createElement(VelocityComponent, { duration: 300, animation: expand ? "slideDown" : "slideUp", interruptBehavior: "queue" },
                React.createElement("ul", null, this.getSubCom(child, lev, index)))));
    }
}
ParTreeItem.defaultProps = {
    childField: "children",
};
export default ParTreeItem;

==> web-9.0.0.tgz: package/lib/combo/ParTreeItem.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
import { activeStatus, DropItem } from "./DropItem";
import { SlideBox } from "../animate/index";
import { CheckBox } from "../input/index";
class ParTreeItem extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.checkFn = (e) => {
            const dom = e.currentTarget;
            const value = dom.value;
            this.props.checkForPar(value);
        };
        this.toggleExpandFn = (e) => {
            const dom = e.currentTarget;
            const index = dom.dataset.index;
            this.props.toggleExpand(index);
        };
    }
    getCheckbox(text, expand) {
        const { fieldObj, node, index } = this.props;
        const multiply = fieldObj.get("multiply");
        const active = node.get("active");
        const hasChecked = activeStatus.hasSelect === active;
        const checked = activeStatus.select === active;
        const icon = React.createElement(SvgIcon, { className: expand ? "folder-open" : "folder" });
        return multiply ? (React.createElement(CheckBox, { hasChecked: hasChecked, checked: checked, value: index, type: "checkbox", changeHandle: this.checkFn },
            icon,
            React.createElement("span", { className: "combo-text" }, text))) : (React.createElement(React.Fragment, null,
            icon,
            React.createElement("span", { className: "combo-text" }, text)));
    }
    getSubCom(child, lev, oindex) {
        const { fieldObj, clickFn, checkForPar, checkMethod, toggleExpand, formatterDropItem } = this.props;
        const idField = fieldObj.get("idField");
        const multiply = fieldObj.get("multiply");
        return child.map((val, index) => {
            const child = val.get(fieldObj.get("childField"));
            return !child.size ? (React.createElement(DropItem, { key: val.get(idField), node: val, fieldObj: fieldObj, index: `${oindex},${index}`, lev: lev + 1, clickFn: clickFn, formatterDropItem: formatterDropItem, checkMethod: checkMethod, CheckBox: multiply ? CheckBox : undefined })) : (React.createElement(ParTreeItem, { key: val.get(idField), node: val, fieldObj: fieldObj, clickFn: clickFn, index: `${oindex},${index}`, lev: lev + 1, checkForPar: checkForPar, formatterDropItem: formatterDropItem, checkMethod: checkMethod, toggleExpand: toggleExpand }));
        });
    }
    render() {
        const { lev, node, index, fieldObj, formatterDropItem } = this.props;
        const levSpaceStyle = { paddingLeft: `${lev}em`, };
        const text = formatterDropItem
            ? formatterDropItem(node)
            : node.get(fieldObj.get("textField"));
        const expand = node.get("expand");
        const child = node.get(fieldObj.get("childField"));
        return (React.createElement("li", { className: "combo-par-item" },
            React.createElement("div", { className: `m-combo-item`, "data-index": index, onClick: this.toggleExpandFn },
                React.createElement("span", { className: "g-item-text", style: levSpaceStyle }, this.getCheckbox(text, expand)),
                React.createElement(SvgIcon, { className: `arrow-${expand ? "up" : "down"}` })),
            React.createElement(SlideBox, { slide: expand },
                React.createElement("ul", null, this.getSubCom(child, lev, index)))));
    }
}
ParTreeItem.defaultProps = {
    childField: "children",
};
export default ParTreeItem;
